@@ -1,6 +1,7 @@
 require File.expand_path('../../test_helper', __FILE__)
 require 'test_runner'
 require 'mocha/configuration'
+require 'introspection'
 
 module AcceptanceTest
   
@@ -35,4 +36,6 @@ module AcceptanceTest
     Mocha::Mockery.instance.logger = @original_logger
   end
   
+  include Introspection::Assertions
+  
 end
